# Download MNIST

library(snedata)

mnist <- download_mnist()

# first 60,000 instances are the training set
mnist_train <- head(mnist, 60000)
# the remaining 10,000 are the test set
mnist_test <- tail(mnist, 10000)

# PCA on 1000 random training examples
mnist_r1000 <- mnist_train[sample(nrow(mnist_train), 1000), ]
pca <- prcomp(mnist_r1000[, 1:784], retx = TRUE, rank. = 2)
# plot the scores of the first two components
plot(pca$x[, 1:2], type = 'n')
text(pca$x[, 1:2], labels = mnist_r1000$Label,
     col = rainbow(length(levels(mnist$Label)))[mnist_r1000$Label])


# DataExplorer: https://cran.r-project.org/web/packages/DataExplorer/vignettes/dataexplorer-intro.html

library(pacman)
p_load(tidyverse, nycflights13, DataExplorer)

data_list <- list(airlines, airports, flights, planes, weather)

plot_str(data_list)

plot_str(data_list, type = "r")

merge_airlines <- merge(flights, airlines, by = "carrier", all.x = TRUE)
merge_planes <- merge(merge_airlines, planes, by = "tailnum", all.x = TRUE, suffixes = c("_flights", "_planes"))
merge_airports_origin <- merge(merge_planes, airports, by.x = "origin", by.y = "faa", all.x = TRUE, suffixes = c("_carrier", "_origin"))
final_data <- merge(merge_airports_origin, airports, by.x = "dest", by.y = "faa", all.x = TRUE, suffixes = c("_origin", "_dest"))

introduce(final_data)

plot_intro(final_data)

plot_missing(final_data)

final_data <- drop_columns(final_data, "speed")

plot_missing(final_data)

plot_bar(final_data)

final_data[which(final_data$manufacturer == "AIRBUS INDUSTRIE"),]$manufacturer <- "AIRBUS"
final_data[which(final_data$manufacturer == "CANADAIR LTD"),]$manufacturer <- "CANADAIR"
final_data[which(final_data$manufacturer %in% c("MCDONNELL DOUGLAS AIRCRAFT CO", "MCDONNELL DOUGLAS CORPORATION")),]$manufacturer <- "MCDONNELL DOUGLAS"

plot_bar(final_data$manufacturer)

final_data <- drop_columns(final_data, c("dst_origin", "tzone_origin"))

plot_bar(final_data, with = "arr_delay")

plot_histogram(final_data)

final_data <- update_columns(final_data, "flight", as.factor)

final_data <- drop_columns(final_data, c("year_flights", "tz_origin"))

qq_data <- final_data[, c("arr_delay", "air_time", "distance", "seats")]

plot_qq(qq_data, sampled_rows = 1000L)

log_qq_data <- update_columns(qq_data, 2:4, function(x) log(x + 1))

plot_qq(log_qq_data[, 2:4], sampled_rows = 1000L)

qq_data <- final_data[, c("name_origin", "arr_delay", "air_time", "distance", "seats")]

plot_qq(qq_data, by = "name_origin", sampled_rows = 1000L)

plot_correlation(na.omit(final_data), maxcat = 5L)

plot_correlation(na.omit(final_data), type = "c")
plot_correlation(na.omit(final_data), type = "d")

pca_df <- na.omit(final_data[, c("origin", "dep_delay", "arr_delay", "air_time", "year_planes", "seats")])

plot_prcomp(pca_df, variance_cap = 0.9, nrow = 2L, ncol = 2L)

## Reduce data size for demo purpose
arr_delay_df <- final_data[, c("arr_delay", "month", "day", "hour", "minute", "dep_delay", "distance", "year_planes", "seats")]

## Call boxplot function
plot_boxplot(arr_delay_df, by = "arr_delay")

arr_delay_df2 <- final_data[, c("arr_delay", "dep_time", "dep_delay", "arr_time", "air_time", "distance", "year_planes", "seats")]

plot_scatterplot(arr_delay_df2, by = "arr_delay", sampled_rows = 1000L)

create_report(final_data)

create_report(final_data, y = "arr_delay")



configure_report(
  add_plot_str = FALSE,
  add_plot_qq = FALSE,
  add_plot_prcomp = FALSE,
  add_plot_boxplot = FALSE,
  add_plot_scatterplot = FALSE,
  global_ggtheme = quote(theme_minimal(base_size = 14))
)

create_report(final_data, config = config)



# Many Datasets

cars %>% head()

cars %>% introduce()

cars %>% create_report(y = "dist")



Cars93 %>% head()

Cars93 %>% introduce()

create_report(y = "Price")



mpg %>% head()

mpg %>% introduce()

mpg %>% create_report(y = "hwy")




diamonds %>% head()

diamonds %>% introduce()

diamonds %>% create_report(y = "price")



airlines %>% introduce()
airlines %>% create_report()

airports %>% introduct()
airports %>% create_report()

planes %>% introduct()
planes %>% create_report()

weather %>% introduct()
weather %>% create_report()

# Summarytools

p_load(summarytools)

cars %>% dfSummary() %>%
  view()

Cars93 %>% dfSummary() %>%
  view()


iris %>% dfSummary() %>%
  view()

diamonds %>% dfSummary() %>%
  view()

flights %>% dfSummary() %>%
  View()

airports %>% dfSummary() %>%
  view()

library(arsenal)

library(radiant)

library(esquisse)

library(dataMaid)

makeDataReport(mpg)

makeDataReport(diamonds)

library(dlookr)

library(explore)

library(exploreR)

library(SmartEDA)

library(autoplotly)

autoplotly(lm(mass ~ height, data = starwars))

autoplotly(lm(mass ~ height), data = starwars)

p <- autoplotly(prcomp(iris[c(1, 2, 3, 4)]), data = iris, colour = 'Species', label = TRUE, label.size = 3, frame = TRUE)




# Merging the nycflight13 tables into one table

# Try this code from the data explorer website.

# https://cran.r-project.org/web/packages/DataExplorer/vignettes/dataexplorer-intro.html

merge_airlines <- merge(flights, airlines, by = "carrier", all.x = TRUE)
merge_planes <- merge(merge_airlines, planes, by = "tailnum", all.x = TRUE, suffixes = c("_flights", "_planes"))
merge_airports_origin <- merge(merge_planes, airports, by.x = "origin", by.y = "faa", all.x = TRUE, suffixes = c("_carrier", "_origin"))
final_data <- merge(merge_airports_origin, airports, by.x = "dest", by.y = "faa", all.x = TRUE, suffixes = c("_origin", "_dest"))


library(forcats)

library(forcats)
f %>% fct_collapse(A = c("A","B"))

planes %>% select(starts_with("manu")) %>% 
  group_by(manufacturer) %>% 
  count()

planes2 <- planes %>% mutate(manu2 = fct_collapse(manufacturer, 
                      AIRBUS = c("AIRBUS INDUSTRIE", "AIRBUS"), 
                      "MCDONNELL DOUGLAS" = c("MCDONNELL DOUGLAS AIRCRAFT CO", "MCDONNELL DOUGLAS CORPORATION","MCDONNELL DOUGLAS")
                      )) 

planes2 %>% select(manu2) %>% 
  group_by(manu2) %>% 
  count() %>% View()

plot_bar(planes2$manu2)

