# The pacman package has the p_load() function that can check if a package is installed and if not it will install it.
# The DataExplorer package has the create_report() function that uses AutoEDA to product a report about all variables.

# https://cran.r-project.org/web/packages/DataExplorer/vignettes/dataexplorer-intro.html#slicing-dicing

library(pacman)

p_load(nycflights13, tidyverse, visdat, naniar, DataExplorer)


airlines <- airlines %>% rename(name_airlines = name)

merge_airlines <- left_join(flights, airlines, by = "carrier")

planes <- planes %>% rename(year_manufacture = year)

merge_planes <- left_join(merge_airlines, planes, by = "tailnum")

airports <- airports %>% rename(name_airport = name)

merge_airports_origin <- left_join(merge_planes, airports, by = c("origin" = "faa"))


final_nycflights13 <- merge_airports_origin

final_nycflights13 <- final_nycflights13 %>% select(-speed)

final_nycflights13 <- final_nycflights13 %>% mutate( manufacturer = fct_collapse(manufacturer, 
                               AIRBUS = c("AIRBUS INDUSTRIE", "AIRBUS"), 
                               "MCDONNELL DOUGLAS" = c("MCDONNELL DOUGLAS AIRCRAFT CO", "MCDONNELL DOUGLAS CORPORATION","MCDONNELL DOUGLAS") )) 



final_nycflights13 <- final_nycflights13 %>% select(-dst, -tzone, -tz)

temporal_features <- c("month", "day", "hour", "minute")
final_nycflights13 <- update_columns(final_nycflights13, temporal_features, as.factor)   # From DataExplorer package

str(final_nycflights13[, c("month", "day", "hour", "minute")])

config <- configure_report(
  add_plot_str = TRUE,
  add_plot_qq = FALSE,
  add_plot_prcomp = FALSE,
  add_plot_boxplot = TRUE,
  add_plot_scatterplot = TRUE,
  global_ggtheme = quote(theme_minimal(base_size = 14))
)
create_report(final_nycflights13, y = "arr_delay", config = config)
